summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--cmake/QtBaseGlobalTargets.cmake6
1 files changed, 3 insertions, 3 deletions
diff --git a/cmake/QtBaseGlobalTargets.cmake b/cmake/QtBaseGlobalTargets.cmake
index de5aaca2a1..355a24eaed 100644
--- a/cmake/QtBaseGlobalTargets.cmake
+++ b/cmake/QtBaseGlobalTargets.cmake
@@ -227,15 +227,15 @@ unset(__qt_cmake_extra)
# and then calls add_subdirectory on the provided project path.
set(__qt_cmake_standalone_test_bin_name "qt-cmake-standalone-test")
set(__qt_cmake_private_path
- "${QT_BUILD_INTERNALS_RELOCATABLE_INSTALL_PREFIX}/${INSTALL_BINDIR}/qt-cmake-private")
+ "${QT_STAGING_PREFIX}/${INSTALL_BINDIR}/qt-cmake-private")
set(__qt_cmake_standalone_test_path
"${__build_internals_install_dir}/${__build_internals_standalone_test_template_dir}")
if(QT_WILL_INSTALL)
# Need to prepend the install prefix when doing prefix builds, because the build internals
# install dir is relative in that case..
qt_path_join(__qt_cmake_standalone_test_path
- "${QT_BUILD_INTERNALS_RELOCATABLE_INSTALL_PREFIX}"
+ "${QT_STAGING_PREFIX}"
"${__qt_cmake_standalone_test_path}")
endif()
if(UNIX)
@@ -227,15 +227,15 @@ unset(__qt_cmake_extra)
"${__build_internals_install_dir}/${__build_internals_standalone_test_template_dir}")
if(QT_WILL_INSTALL)
- # Need to prepend the install prefix when doing prefix builds, because the build internals
+ # Need to prepend the staging prefix when doing prefix builds, because the build internals
# install dir is relative in that case..
qt_path_join(__qt_cmake_standalone_test_path